# Research on Tabular Deep Learning<!-- omit in toc -->
This repository contains:
- source code for our papers and projects on tabular Deep Learning. See the ["Projects"](#projects) section below.
- `rtdl` - a PyTorch-based package providing a user-friendly API for the main models and concepts from the projects. See the [documentation](https://yandex-research.github.io/rtdl).

Feel free to [open issues](https://github.com/yandex-research/rtdl/issues) and [start discussions](https://github.com/yandex-research/rtdl/discussions) related to the projects and the library.

## Projects

(technical note: for each active project, you should have a separate clone of the whole repository and a separate virtual environment)

|                       Name                       |                           Folder                            |   Comment    |
| :----------------------------------------------: | :---------------------------------------------------------: | :----------: |
| Revisiting Deep Learning Models for Tabular Data | [projects/revisiting-models](./projects/revisiting-models/) | NeurIPS 2021 |
